isMatch method
Returns true iff value matches the expressions current value.
Implementation
@protected
bool isMatch(LogicValue value, LogicValue expressionValue) =>
expressionValue == value;
Returns true iff value matches the expressions current value.
@protected
bool isMatch(LogicValue value, LogicValue expressionValue) =>
expressionValue == value;