CaseItem class
Represents a single case within a Case block.
Constructors
-
CaseItem(Logic value, List<
Conditional> then) -
Executes
thenwhenvaluematches.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
then
→ List<
Conditional> -
A List of Conditionals to execute when value is matched.
final
- value → Logic
-
The value to match against.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited