calculateReceivers method
The same as receivers, but uncached for situations where the list of conditionals may still be modified or to compute the cached result for receivers itself.
Implementation
@override
@protected
List<Logic> calculateReceivers() => receivers;