generatedDefinitionType property
What kind of SystemVerilog definition this Module generates, or whether it does at all.
By default, this is automatically calculated based on the return value of definitionVerilog.
Implementation
@override
DefinitionGenerationType get generatedDefinitionType =>
DefinitionGenerationType.none;