nextPosedge property
Future<LogicValueChanged>
get
nextPosedge
Triggers at most once, the next time that this Logic changes
value at the end of a Simulator tick from 0 to 1.
Throws an exception if width is not 1.
Implementation
Future<LogicValueChanged> get nextPosedge => _wire.nextPosedge;