clone method

  1. @override
  2. @mustBeOverridden
LogicNet clone({
  1. String? name,
})
override

Makes a copy of this, optionally with the specified name, but the same width.

It is expected that any implementation will override this in a way that returns the same type as itself.

Implementation

@override
@mustBeOverridden
LogicNet clone({String? name}) => super.clone(name: name) as LogicNet;