Triggers at most once, the next time that this Logic changes value at the end of a Simulator tick from 0 to 1.
0
1
Throws an exception if width is not 1.
@override // Can rely on `packed` here because it must be 1 bit. Future<LogicValueChanged> get nextPosedge => packed.nextPosedge;