packed property
Implementation
@override
// If this is an output port, we have to regenerate each time to avoid
// illegal reuse inside and outside the module. This is unique for outputs.
Logic get packed => isOutput ? _genPacked() : _packed;
@override
// If this is an output port, we have to regenerate each time to avoid
// illegal reuse inside and outside the module. This is unique for outputs.
Logic get packed => isOutput ? _genPacked() : _packed;