LogicSwizzle extension

Allows lists of Logics to be swizzled.

on

Methods

rswizzle() Logic

Available on List<Logic>, provided by the LogicSwizzle extension

Performs a concatenation operation on the list of signals, where index 0 of this list is the least significant bit(s).
swizzle() Logic

Available on List<Logic>, provided by the LogicSwizzle extension

Performs a concatenation operation on the list of signals, where index 0 of this list is the most significant bit(s).