PipelineStageInfo class

Information and accessors associated with a Pipeline stage.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage int
The index of the current stage in the associated Pipeline.
final

Methods

get(Logic identifier, [int stageAdjustment = 0]) Logic
Returns a staged version of identifier at the current stage, adjusted by the amount of stageAdjustment.
getAbs(Logic identifier, int stageIndex) Logic
Returns the output of identifier at the specified absolute stageIndex stage, if other than the current stage. Otherwise, returns the same thing as get, for the current stage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited