get method
Returns a staged version of identifier at the current stage, adjusted by
the amount of stageAdjustment.
Typically, your pipeline will consist of a lot of p.get(x) type calls,
but if you want to combinationally access a value of a signal from another
stage, you can access it relatively using stageAdjustment. For example,
p.get(x, -1) will access the value of x at the output of one stage
prior.
Implementation
Logic get(Logic identifier, [int stageAdjustment = 0]) =>
getAbs(identifier, stage + stageAdjustment);