registerEndOfSimulationAction static method
void
registerEndOfSimulationAction(
- dynamic action()
Registers an arbitrary action to be executed at the end of the
simulation.
The simulation will not be marked as ended until these actions complete.
If action returns a Future, it will be awaited.
Implementation
static void registerEndOfSimulationAction(dynamic Function() action) {
_endOfSimulationActions.add(action);
}