LogicSwizzle extension
Allows lists of Logics to be swizzled.
Methods
-
rswizzle(
) → Logic -
Available on List<
Performs a concatenation operation on the list of signals, where index 0 of this list is the least significant bit(s).Logic> , provided by the LogicSwizzle extension -
swizzle(
) → Logic -
Available on List<
Performs a concatenation operation on the list of signals, where index 0 of this list is the most significant bit(s).Logic> , provided by the LogicSwizzle extension