UnassignableException class
An exception that thrown when a Logic signal fails to put.
- Inheritance
-
- Object
- RohdException
- UnassignableException
Constructors
- UnassignableException(Logic logic, {String? reason})
- Creates an exception for when a Logic is marked as unassignable but something tried to assign to it.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited